@@ -227,6 +227,9 @@ class Data::DPath::Context {
 
 }
 
+# help the CPAN indexer
+package Data::DPath::Context;
+
 1;
 
 __END__
@@ -270,42 +273,3 @@ This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =cut
-__END__
-
-/foo[ isa("Foo")  ]/
-
-    @filtered = grep { eval $condition } @points;
-
-/foo[ reallyhotstuff("Foo")  ]/
-
-/foo[ index == 7  ]/
-
-package Data::DPath::Filters;
-        our $index;
-
-        sub reallyhotstuff {
-                (@args) = @_;
-                # $_->ref sowieso da
-                return 1 or 0;
-        }
-
-        sub index { $index };
-}
-
-package Data::DPath::Context;
-sub _filter {
-
-        @points = map { new Point( ref => $_ } @refs;
-
-                        @filtered = grep { eval 'reallyhotstuff("Foo")' } @points;
-                        grep { $_ = ${ $_->ref }; foo() } @list;
-                        {
-                                package Data::DPath::Filters;
-                                local $index = -1;
-                                grep { $index++; $_ = ${ $_->ref }; eval $condition; } @points;
-                        }
-}
-# moose type constraints, haben check methode
-# haben Syntax, diese stehlen
-# subtypes definieren
-
